from setuptools import setup, find_packages

setup(
    name='sum_arun_test',
    version='0.1.2',
    packages=find_packages(),
    author='Arun Uday',
    description='A Python SDK for Testing sdk',
)
